# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-09-14 19:35
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('screenshot', '0003_auto_20160803_1243'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='screenshot',
            name='_id',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-09-14 08:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0012_auto_20160501_1849'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='answer',
            options={'ordering': ['-accepted', '-last_update'], 'verbose_name': 'Ответ', 'verbose_name_plural': 'Ответы'},
        ),
    ]
